@@ -3,17 +3,18 @@ use Moo;
 
 with 'HTML::Video::Embed::Module';
 
-sub _build_domain_reg{
+our $VERSION = '0.016000';
+$VERSION = eval $VERSION;
+
+sub domain_reg {
     return qr/liveleak\.com/;
 }
 
-sub _build_validate_reg{
-    return qr/^(?:\w{3}_\w{10}|\w{12})$/;
-}
-
-sub process{
+sub process {
     my ( $self, $embeder, $uri ) = @_;
 
+    return undef if $embeder->secure;
+
     my $query_param = 'i';
 
     my $vid = $uri->query_param('i');
@@ -23,7 +24,7 @@ sub process{
     }
     $vid ||= '';
 
-    if ( $vid =~ m/${ \$self->validate_reg }/ ){
+    if ( $vid =~ m/^(?:\w{3}_\w{10}|\w{12})$/ ) {
         return qq|<iframe class="${ \$embeder->class }" src="http://www.liveleak.com/ll_embed?${query_param}=${vid}" frameborder="0" allowfullscreen="1"></iframe>|;
     }
 
